.. release procedure

Procedure:

1. update release version/date in ``CHANGES.rst``
2. create GitHub Release with new version tag, it will create a release on PyPI.
   tag MUST following semver. e.g.: ``2.3.1``
3. check PyPI page: https://pypi.org/p/sphinx-intl
4. prepareing for the next release: bump version in ``CHANGES.rst`` then commit/push it onto GitHub
